@@ -9,23 +9,24 @@ class TestI18nLoad < Test::Unit::TestCase
     # and proper initialization of i18n.
     code = <<-RUBY
       require 'bundler/inline'
+      require 'test/unit'
 
       gemfile do
         source 'https://rubygems.org'
-        gem 'minitest', '5.25.5'
         gem 'i18n'
       end
 
-      require 'minitest/autorun'
       require 'i18n'
 
-      class TestI18nLoad < Minitest::Test
+      class TestI18nLoad < Test::Unit::TestCase
         def test_faker_i18n
           I18n.available_locales = [:en]
-          refute_predicate I18n.backend, :initialized?
+
+          refute I18n.backend.initialized?
+
           I18n.translate('doesnt matter just triggering a lookup')
 
-          assert_predicate I18n.backend, :initialized?
+          assert I18n.backend.initialized?
 
           assert require File.expand_path('#{File.dirname(__FILE__)}/../lib/faker')
 
@@ -37,6 +38,6 @@ class TestI18nLoad < Test::Unit::TestCase
     cmd = %( ruby -e "#{code}" )
     output, status = Open3.capture2e(cmd)
 
-    assert_equal 0, status, output
+    assert_equal(0, status, output)
   end
 end
